@@ -32,29 +32,24 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_BT_CHOKE_MESSAGE_H_
-#define _D_BT_CHOKE_MESSAGE_H_
+#ifndef D_BT_CHOKE_MESSAGE_H
+#define D_BT_CHOKE_MESSAGE_H
 
 #include "ZeroBtMessage.h"
 
 namespace aria2 {
 
-class BtChokeMessage;
-
-typedef SharedHandle<BtChokeMessage> BtChokeMessageHandle;
-
 class BtChokeMessage : public ZeroBtMessage {
 public:
   BtChokeMessage();
 
   static const uint8_t ID = 0;
 
-  static const std::string NAME;
+  static const char NAME[];
 
   virtual void doReceivedAction();
 
-  static SharedHandle<BtChokeMessage> create
-  (const unsigned char* data, size_t dataLength);
+  static BtChokeMessage* create(const unsigned char* data, size_t dataLength);
 
   virtual bool sendPredicate() const;
 
@@ -63,4 +58,4 @@ public:
 
 } // namespace aria2
 
-#endif // _D_CHOKE_MESSAGE_H_
+#endif // D_CHOKE_MESSAGE_H
