@@ -32,15 +32,13 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_BT_MESSAGE_H_
-#define _D_BT_MESSAGE_H_
+#ifndef D_BT_MESSAGE_H
+#define D_BT_MESSAGE_H
 
 #include "common.h"
 
 #include <string>
-#include <deque>
 
-#include "SharedHandle.h"
 #include "BtAbortOutstandingRequestEvent.h"
 #include "BtCancelSendingPieceEvent.h"
 #include "BtChokingEvent.h"
@@ -51,9 +49,9 @@ class BtEvent;
 
 class BtMessage {
 private:
-  uint8_t _id;
+  uint8_t id_;
 public:
-  BtMessage(uint8_t id):_id(id) {}
+  BtMessage(uint8_t id):id_(id) {}
 
   virtual ~BtMessage() {}
 
@@ -63,13 +61,13 @@ public:
 
   virtual bool isUploading() = 0;
 
-  uint8_t getId() { return _id; }
+  uint8_t getId() { return id_; }
 
   virtual void doReceivedAction() = 0;
 
   virtual void send() = 0;
 
-  virtual bool validate(std::deque<std::string>& errors) = 0;
+  virtual void validate() = 0;
 
   virtual void onAbortOutstandingRequestEvent
   (const BtAbortOutstandingRequestEvent& event) = 0;
@@ -85,9 +83,6 @@ public:
 
 };
 
-typedef SharedHandle<BtMessage> BtMessageHandle;
-typedef std::deque<BtMessageHandle> BtMessages;
-
 } // namespace aria2
 
-#endif // _D_BT_MESSAGE_H_
+#endif // D_BT_MESSAGE_H
