@@ -37,6 +37,7 @@
 #include "RequestGroup.h"
 #include "Option.h"
 #include "Logger.h"
+#include "LogFactory.h"
 #include "DownloadHandlerConstants.h"
 #include "File.h"
 #include "PieceStorage.h"
@@ -46,6 +47,11 @@
 #include "Exception.h"
 #include "DownloadContext.h"
 #include "download_helper.h"
+#include "fmt.h"
+#include "ValueBaseBencodeParser.h"
+#include "DiskWriter.h"
+#include "AbstractSingleDiskAdaptor.h"
+#include "BencodeDiskWriter.h"
 
 namespace aria2 {
 
@@ -53,10 +59,7 @@ BtPostDownloadHandler::BtPostDownloadHandler()
 {
   SharedHandle<RequestGroupCriteria> cri
     (new ContentTypeRequestGroupCriteria
-     (DownloadHandlerConstants::getBtContentTypes().begin(),
-      DownloadHandlerConstants::getBtContentTypes().end(),
-      DownloadHandlerConstants::getBtExtensions().begin(),
-      DownloadHandlerConstants::getBtExtensions().end()));
+     (getBtContentTypes(), getBtExtensions()));
   setCriteria(cri);
 }
 
@@ -66,25 +69,47 @@ void BtPostDownloadHandler::getNextRequestGroups
 (std::vector<SharedHandle<RequestGroup> >& groups,
  RequestGroup* requestGroup)
 {
-  getLogger()->info("Generating RequestGroups for Torrent file %s",
-                    requestGroup->getFirstFilePath().c_str());
-  std::string content;
-  try {
-    requestGroup->getPieceStorage()->getDiskAdaptor()->openExistingFile();
-    content = util::toString(requestGroup->getPieceStorage()->getDiskAdaptor());
-    requestGroup->getPieceStorage()->getDiskAdaptor()->closeFile();    
-  } catch(Exception& e) {
-    requestGroup->getPieceStorage()->getDiskAdaptor()->closeFile();
-    throw;
+  A2_LOG_INFO(fmt("Generating RequestGroups for Torrent file %s",
+                  requestGroup->getFirstFilePath().c_str()));
+  SharedHandle<ValueBase> torrent;
+  if(requestGroup->inMemoryDownload()) {
+    const SharedHandle<DiskWriter>& dw =
+      static_pointer_cast<AbstractSingleDiskAdaptor>
+      (requestGroup->getPieceStorage()->getDiskAdaptor())->getDiskWriter();
+    const SharedHandle<bittorrent::BencodeDiskWriter>& bdw =
+      static_pointer_cast<bittorrent::BencodeDiskWriter>(dw);
+    int error = bdw->finalize();
+    if(error == 0) {
+      torrent = bdw->getResult();
+    }
+  } else {
+    std::string content;
+    try {
+      requestGroup->getPieceStorage()->getDiskAdaptor()->openExistingFile();
+      content = util::toString(requestGroup->getPieceStorage()
+                               ->getDiskAdaptor());
+      requestGroup->getPieceStorage()->getDiskAdaptor()->closeFile();
+    } catch(Exception& e) {
+      requestGroup->getPieceStorage()->getDiskAdaptor()->closeFile();
+      throw;
+    }
+    ssize_t error;
+    torrent = bittorrent::ValueBaseBencodeParser().parseFinal
+      (content.c_str(), content.size(), error);
+  }
+  if(!torrent) {
+    throw DL_ABORT_EX2("Could not parse BitTorrent metainfo",
+                       error_code::BENCODE_PARSE_ERROR);
   }
   std::vector<SharedHandle<RequestGroup> > newRgs;
   createRequestGroupForBitTorrent(newRgs, requestGroup->getOption(),
                                   std::vector<std::string>(),
-                                  content);
+                                  "",
+                                  torrent);
   requestGroup->followedBy(newRgs.begin(), newRgs.end());
   SharedHandle<MetadataInfo> mi =
     createMetadataInfoFromFirstFileEntry(requestGroup->getDownloadContext());
-  if(!mi.isNull()) {
+  if(mi) {
     setMetadataInfo(newRgs.begin(), newRgs.end(), mi);
   }
   groups.insert(groups.end(), newRgs.begin(), newRgs.end());
