@@ -42,6 +42,7 @@
 #include "util.h"
 #include "fmt.h"
 #include "DownloadEngine.h"
+#include "DownloadContext.h"
 
 namespace aria2 {
 
@@ -60,10 +61,10 @@ void BtStopDownloadCommand::preProcess()
   if(btRuntime_->isHalt() || pieceStorage_->downloadFinished()) {
     enableExit();
   }
-  if(checkPoint_.difference(global::wallclock) >= timeout_) {
-    A2_LOG_NOTICE(fmt("GID#%s Stop downloading torrent due to"
-                      " --bt-stop-timeout option.",
-                      util::itos(requestGroup_->getGID()).c_str()));
+  if(checkPoint_.difference(global::wallclock()) >= timeout_) {
+    A2_LOG_NOTICE(fmt(_("GID#%" PRId64 " Stop downloading torrent due to"
+                        " --bt-stop-timeout option."),
+                      requestGroup_->getGID()));
     requestGroup_->setForceHaltRequested(true);
     getDownloadEngine()->setRefreshInterval(0);
     enableExit();
@@ -72,8 +73,9 @@ void BtStopDownloadCommand::preProcess()
 
 void BtStopDownloadCommand::process()
 {
-  if(requestGroup_->calculateStat().getDownloadSpeed() > 0) {
-    checkPoint_ = global::wallclock;
+  NetStat& stat = requestGroup_->getDownloadContext()->getNetStat();
+  if(stat.calculateDownloadSpeed() > 0) {
+    checkPoint_ = global::wallclock();
   }
 }
 
