@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -37,9 +37,11 @@
 
 namespace aria2 {
 
-const std::string BtUnchokeMessage::NAME("unchoke");
+const char BtUnchokeMessage::NAME[] = "unchoke";
 
-SharedHandle<BtUnchokeMessage> BtUnchokeMessage::create
+BtUnchokeMessage::BtUnchokeMessage():ZeroBtMessage(ID, NAME) {}
+
+BtUnchokeMessage* BtUnchokeMessage::create
 (const unsigned char* data, size_t dataLength)
 {
   return ZeroBtMessage::create<BtUnchokeMessage>(data, dataLength);
@@ -47,19 +49,19 @@ SharedHandle<BtUnchokeMessage> BtUnchokeMessage::create
 
 void BtUnchokeMessage::doReceivedAction()
 {
-  if(_metadataGetMode) {
+  if(isMetadataGetMode()) {
     return;
   }
-  peer->peerChoking(false);
+  getPeer()->peerChoking(false);
 }
 
 bool BtUnchokeMessage::sendPredicate() const
 {
-  return peer->amChoking();
+  return getPeer()->amChoking();
 }
 
 void BtUnchokeMessage::onSendComplete() {
-  peer->amChoking(false);
+  getPeer()->amChoking(false);
 }
 
 } // namespace aria2
