@@ -46,24 +46,21 @@ class DHTMessageDispatcher;
 class DHTMessageFactory;
 class DHTTaskQueue;
 class DHTAbstractTask;
-class Logger;
 
 class DHTTaskFactoryImpl:public DHTTaskFactory {
 private:
   SharedHandle<DHTNode> localNode_;
 
-  WeakHandle<DHTRoutingTable> routingTable_;
+  DHTRoutingTable* routingTable_;
 
-  WeakHandle<DHTMessageDispatcher> dispatcher_;
+  DHTMessageDispatcher* dispatcher_;
 
-  WeakHandle<DHTMessageFactory> factory_;
-  
-  WeakHandle<DHTTaskQueue> taskQueue_;
+  DHTMessageFactory* factory_;
+
+  DHTTaskQueue* taskQueue_;
 
   time_t timeout_;
 
-  Logger* logger_;
-
   void setCommonProperty(const SharedHandle<DHTAbstractTask>& task);
 public:
   DHTTaskFactoryImpl();
@@ -72,7 +69,7 @@ public:
 
   virtual SharedHandle<DHTTask>
   createPingTask(const SharedHandle<DHTNode>& remoteNode,
-                 size_t numRetry = 0);
+                 int numRetry = 0);
 
   virtual SharedHandle<DHTTask>
   createNodeLookupTask(const unsigned char* targetID);
@@ -81,7 +78,7 @@ public:
 
   virtual SharedHandle<DHTTask>
   createPeerLookupTask(const SharedHandle<DownloadContext>& ctx,
-                       const SharedHandle<BtRuntime>& btRuntime,
+                       uint16_t tcpPort,
                        const SharedHandle<PeerStorage>& peerStorage);
 
   virtual SharedHandle<DHTTask>
@@ -91,13 +88,13 @@ public:
   createReplaceNodeTask(const SharedHandle<DHTBucket>& bucket,
                         const SharedHandle<DHTNode>& newNode);
 
-  void setRoutingTable(const WeakHandle<DHTRoutingTable> routingTable);
+  void setRoutingTable(DHTRoutingTable* routingTable);
 
-  void setMessageDispatcher(const WeakHandle<DHTMessageDispatcher> dispatcher);
+  void setMessageDispatcher(DHTMessageDispatcher* dispatcher);
 
-  void setMessageFactory(const WeakHandle<DHTMessageFactory> factory);
+  void setMessageFactory(DHTMessageFactory* factory);
 
-  void setTaskQueue(const WeakHandle<DHTTaskQueue> taskQueue);
+  void setTaskQueue(DHTTaskQueue* taskQueue);
 
   void setLocalNode(const SharedHandle<DHTNode>& localNode);
 
