@@ -46,18 +46,16 @@
 #include "FtpTunnelRequestCommand.h"
 #include "DlAbortEx.h"
 #include "Logger.h"
+#include "LogFactory.h"
 #include "message.h"
 #include "prefs.h"
 #include "HttpConnection.h"
-#include "Socket.h"
-#include "DownloadContext.h"
+#include "SocketCore.h"
 #include "util.h"
 #include "AuthConfigFactory.h"
 #include "AuthConfig.h"
-#include "RequestGroupMan.h"
-#include "FileAllocationEntry.h"
-#include "CheckIntegrityEntry.h"
-#include "ServerStatMan.h"
+#include "fmt.h"
+#include "SocketRecvBuffer.h"
 
 namespace aria2 {
 
@@ -77,8 +75,8 @@ Command* FtpInitiateConnectionCommand::createNextCommand
  const SharedHandle<Request>& proxyRequest)
 {
   Command* command;
-  if(!proxyRequest.isNull()) {
-    std::map<std::string, std::string> options;
+  if(proxyRequest) {
+    std::string options;
     SharedHandle<SocketCore> pooledSocket;
     std::string proxyMethod = resolveProxyMethod(getRequest()->getProtocol());
     if(proxyMethod == V_GET) {
@@ -92,21 +90,21 @@ Command* FtpInitiateConnectionCommand::createNextCommand
          (getRequest(), getOption().get())->getUser(),
          proxyRequest->getHost(), proxyRequest->getPort());
     }
-    if(pooledSocket.isNull()) {
-      if(getLogger()->info()) {
-        getLogger()->info(MSG_CONNECTING_TO_SERVER,
-                          util::itos(getCuid()).c_str(), addr.c_str(), port);
-      }
+    if(!pooledSocket) {
+      A2_LOG_INFO(fmt(MSG_CONNECTING_TO_SERVER,
+                      getCuid(), addr.c_str(), port));
       createSocket();
       getSocket()->establishConnection(addr, port);
-      
+
       getRequest()->setConnectedAddrInfo(hostname, addr, port);
       if(proxyMethod == V_GET) {
         // Use GET for FTP via HTTP proxy.
         getRequest()->setMethod(Request::METHOD_GET);
+        SharedHandle<SocketRecvBuffer> socketRecvBuffer
+          (new SocketRecvBuffer(getSocket()));
         SharedHandle<HttpConnection> hc
-          (new HttpConnection(getCuid(), getSocket()));
-        
+          (new HttpConnection(getCuid(), getSocket(), socketRecvBuffer));
+
         HttpRequestCommand* c =
           new HttpRequestCommand(getCuid(), getRequest(), getFileEntry(),
                                  getRequestGroup(), hc, getDownloadEngine(),
@@ -126,18 +124,21 @@ Command* FtpInitiateConnectionCommand::createNextCommand
     } else {
       setConnectedAddrInfo(getRequest(), hostname, pooledSocket);
       if(proxyMethod == V_TUNNEL) {
+        // options contains "baseWorkingDir"
         command =
           new FtpNegotiationCommand(getCuid(), getRequest(), getFileEntry(),
                                     getRequestGroup(), getDownloadEngine(),
                                     pooledSocket,
                                     FtpNegotiationCommand::SEQ_SEND_CWD_PREP,
-                                    options["baseWorkingDir"]);
+                                    options);
       } else if(proxyMethod == V_GET) {
         // Use GET for FTP via HTTP proxy.
         getRequest()->setMethod(Request::METHOD_GET);
+        SharedHandle<SocketRecvBuffer> socketRecvBuffer
+          (new SocketRecvBuffer(pooledSocket));
         SharedHandle<HttpConnection> hc
-          (new HttpConnection(getCuid(), pooledSocket));
-        
+          (new HttpConnection(getCuid(), pooledSocket, socketRecvBuffer));
+
         HttpRequestCommand* c =
           new HttpRequestCommand(getCuid(), getRequest(), getFileEntry(),
                                  getRequestGroup(), hc, getDownloadEngine(),
@@ -150,18 +151,16 @@ Command* FtpInitiateConnectionCommand::createNextCommand
       }
     }
   } else {
-    std::map<std::string, std::string> options;
+    std::string options;
     SharedHandle<SocketCore> pooledSocket =
       getDownloadEngine()->popPooledSocket
       (options, resolvedAddresses,
        getRequest()->getPort(),
        getDownloadEngine()->getAuthConfigFactory()->createAuthConfig
        (getRequest(), getOption().get())->getUser());
-    if(pooledSocket.isNull()) {
-      if(getLogger()->info()) {
-        getLogger()->info(MSG_CONNECTING_TO_SERVER,
-                          util::itos(getCuid()).c_str(), addr.c_str(), port);
-      }
+    if(!pooledSocket) {
+      A2_LOG_INFO(fmt(MSG_CONNECTING_TO_SERVER,
+                      getCuid(), addr.c_str(), port));
       createSocket();
       getSocket()->establishConnection(addr, port);
       FtpNegotiationCommand* c =
@@ -171,12 +170,13 @@ Command* FtpInitiateConnectionCommand::createNextCommand
       getRequest()->setConnectedAddrInfo(hostname, addr, port);
       command = c;
     } else {
+      // options contains "baseWorkingDir"
       command =
         new FtpNegotiationCommand(getCuid(), getRequest(), getFileEntry(),
                                   getRequestGroup(), getDownloadEngine(),
                                   pooledSocket,
                                   FtpNegotiationCommand::SEQ_SEND_CWD_PREP,
-                                  options["baseWorkingDir"]);
+                                  options);
       setConnectedAddrInfo(getRequest(), hostname, pooledSocket);
     }
   }
