@@ -52,13 +52,14 @@
 #include "util.h"
 #include "Option.h"
 #include "Logger.h"
+#include "LogFactory.h"
 #include "Segment.h"
 #include "DownloadContext.h"
 #include "DefaultBtProgressInfoFile.h"
 #include "RequestGroupMan.h"
 #include "DownloadFailureException.h"
-#include "Socket.h"
-#include "StringFormat.h"
+#include "SocketCore.h"
+#include "fmt.h"
 #include "DiskAdaptor.h"
 #include "SegmentMan.h"
 #include "AuthConfigFactory.h"
@@ -70,10 +71,12 @@
 #include "HttpRequest.h"
 #include "HttpResponse.h"
 #include "DlRetryEx.h"
-#include "CookieStorage.h"
-#include "ServerStatMan.h"
-#include "FileAllocationEntry.h"
 #include "CheckIntegrityEntry.h"
+#include "error_code.h"
+#include "SocketRecvBuffer.h"
+#ifdef ENABLE_MESSAGE_DIGEST
+# include "ChecksumCheckIntegrityEntry.h"
+#endif // ENABLE_MESSAGE_DIGEST
 
 namespace aria2 {
 
@@ -83,14 +86,16 @@ FtpNegotiationCommand::FtpNegotiationCommand
  const SharedHandle<FileEntry>& fileEntry,
  RequestGroup* requestGroup,
  DownloadEngine* e,
- const SocketHandle& socket,
+ const SharedHandle<SocketCore>& socket,
  Seq seq,
  const std::string& baseWorkingDir):
-  AbstractCommand(cuid, req, fileEntry, requestGroup, e, socket), sequence_(seq),
+  AbstractCommand(cuid, req, fileEntry, requestGroup, e, socket),
+  sequence_(seq),
   ftp_(new FtpConnection(cuid, socket, req,
                         e->getAuthConfigFactory()->createAuthConfig
                         (req, requestGroup->getOption().get()),
-                        getOption().get()))
+                         getOption().get())),
+  pasvPort_(0)
 {
   ftp_->setBaseWorkingDir(baseWorkingDir);
   if(seq == SEQ_RECV_GREETING) {
@@ -151,12 +156,12 @@ bool FtpNegotiationCommand::recvGreeting() {
   disableWriteCheckSocket();
   setReadCheckSocket(getSocket());
 
-  unsigned int status = ftp_->receiveResponse();
+  int status = ftp_->receiveResponse();
   if(status == 0) {
     return false;
   }
   if(status != 220) {
-    throw DL_ABORT_EX(EX_CONNECTION_FAILED);
+    throw DL_ABORT_EX2(EX_CONNECTION_FAILED, error_code::FTP_PROTOCOL_ERROR);
   }
   sequence_ = SEQ_SEND_USER;
 
@@ -174,7 +179,7 @@ bool FtpNegotiationCommand::sendUser() {
 }
 
 bool FtpNegotiationCommand::recvUser() {
-  unsigned int status = ftp_->receiveResponse();
+  int status = ftp_->receiveResponse();
   switch(status) {
   case 0:
     return false;
@@ -185,7 +190,8 @@ bool FtpNegotiationCommand::recvUser() {
     sequence_ = SEQ_SEND_PASS;
     break;
   default:
-    throw DL_ABORT_EX(StringFormat(EX_BAD_STATUS, status).str());
+    throw DL_ABORT_EX2(fmt(EX_BAD_STATUS, status),
+                       error_code::FTP_PROTOCOL_ERROR);
   }
   return true;
 }
@@ -201,12 +207,13 @@ bool FtpNegotiationCommand::sendPass() {
 }
 
 bool FtpNegotiationCommand::recvPass() {
-  unsigned int status = ftp_->receiveResponse();
+  int status = ftp_->receiveResponse();
   if(status == 0) {
     return false;
   }
   if(status != 230) {
-    throw DL_ABORT_EX(StringFormat(EX_BAD_STATUS, status).str());
+    throw DL_ABORT_EX2(fmt(EX_BAD_STATUS, status),
+                       error_code::FTP_PROTOCOL_ERROR);
   }
   sequence_ = SEQ_SEND_TYPE;
   return true;
@@ -223,12 +230,13 @@ bool FtpNegotiationCommand::sendType() {
 }
 
 bool FtpNegotiationCommand::recvType() {
-  unsigned int status = ftp_->receiveResponse();
+  int status = ftp_->receiveResponse();
   if(status == 0) {
     return false;
   }
   if(status != 200) {
-    throw DL_ABORT_EX(StringFormat(EX_BAD_STATUS, status).str());
+    throw DL_ABORT_EX2(fmt(EX_BAD_STATUS, status),
+                       error_code::FTP_PROTOCOL_ERROR);
   }
   sequence_ = SEQ_SEND_PWD;
   return true;
@@ -248,29 +256,28 @@ bool FtpNegotiationCommand::sendPwd()
 bool FtpNegotiationCommand::recvPwd()
 {
   std::string pwd;
-  unsigned int status = ftp_->receivePwdResponse(pwd);
+  int status = ftp_->receivePwdResponse(pwd);
   if(status == 0) {
     return false;
   }
   if(status != 257) {
-    throw DL_ABORT_EX(StringFormat(EX_BAD_STATUS, status).str());
+    throw DL_ABORT_EX2(fmt(EX_BAD_STATUS, status),
+                       error_code::FTP_PROTOCOL_ERROR);
   }
   ftp_->setBaseWorkingDir(pwd);
-  if(getLogger()->info()) {
-    getLogger()->info("CUID#%s - base working directory is '%s'",
-                      util::itos(getCuid()).c_str(), pwd.c_str());
-  }
+  A2_LOG_INFO(fmt("CUID#%" PRId64 " - base working directory is '%s'",
+                  getCuid(), pwd.c_str()));
   sequence_ = SEQ_SEND_CWD_PREP;
   return true;
 }
 
 bool FtpNegotiationCommand::sendCwdPrep()
 {
-  // Calling setReadCheckSocket() is needed when the socket is reused, 
+  // Calling setReadCheckSocket() is needed when the socket is reused,
   setReadCheckSocket(getSocket());
-  util::split(getRequest()->getDir(), std::back_inserter(cwdDirs_),
-              A2STR::SLASH_C);
   cwdDirs_.push_front(ftp_->getBaseWorkingDir());
+  util::split(getRequest()->getDir().begin(), getRequest()->getDir().end(),
+              std::back_inserter(cwdDirs_), '/');
   sequence_ = SEQ_SEND_CWD;
   return true;
 }
@@ -288,7 +295,7 @@ bool FtpNegotiationCommand::sendCwd()
 
 bool FtpNegotiationCommand::recvCwd()
 {
-  unsigned int status = ftp_->receiveResponse();
+  int status = ftp_->receiveResponse();
   if(status == 0) {
     return false;
   }
@@ -297,9 +304,10 @@ bool FtpNegotiationCommand::recvCwd()
     getRequestGroup()->increaseAndValidateFileNotFoundCount();
     if (status == 550)
       throw DL_ABORT_EX2(MSG_RESOURCE_NOT_FOUND,
-                         downloadresultcode::RESOURCE_NOT_FOUND);
+                         error_code::RESOURCE_NOT_FOUND);
     else
-      throw DL_ABORT_EX(StringFormat(EX_BAD_STATUS, status).str());
+      throw DL_ABORT_EX2(fmt(EX_BAD_STATUS, status),
+                         error_code::FTP_PROTOCOL_ERROR);
   }
   cwdDirs_.pop_front();
   if(cwdDirs_.empty()) {
@@ -328,38 +336,25 @@ bool FtpNegotiationCommand::sendMdtm()
 bool FtpNegotiationCommand::recvMdtm()
 {
   Time lastModifiedTime = Time::null();
-  unsigned int status = ftp_->receiveMdtmResponse(lastModifiedTime);
+  int status = ftp_->receiveMdtmResponse(lastModifiedTime);
   if(status == 0) {
     return false;
   }
   if(status == 213) {
     if(lastModifiedTime.good()) {
       getRequestGroup()->updateLastModifiedTime(lastModifiedTime);
-      time_t t = lastModifiedTime.getTime();
-      struct tm* tms = gmtime(&t); // returned struct is statically allocated.
-      if(tms) {
-        if(getLogger()->debug()) {
-          getLogger()->debug("MDTM result was parsed as: %s GMT", asctime(tms));
-        }
-      } else {
-        if(getLogger()->debug()) {
-          getLogger()->debug("gmtime() failed for MDTM result.");
-        }
-      }
+      A2_LOG_DEBUG(fmt("MDTM result was parsed as: %s",
+                       lastModifiedTime.toHTTPDate().c_str()));
     } else {
-      if(getLogger()->debug()) {
-        getLogger()->debug("MDTM response was returned, but it seems not to be"
-                           " a time value as in specified in RFC3659.");
-      }
+      A2_LOG_DEBUG("MDTM response was returned, but it seems not to be"
+                   " a time value as in specified in RFC3659.");
     }
   } else {
-    if(getLogger()->info()) {
-      getLogger()->info("CUID#%s - MDTM command failed.",
-                        util::itos(getCuid()).c_str());
-    }
+    A2_LOG_INFO(fmt("CUID#%" PRId64 " - MDTM command failed.",
+                    getCuid()));
   }
   sequence_ = SEQ_SEND_SIZE;
-  return true;  
+  return true;
 }
 
 bool FtpNegotiationCommand::sendSize() {
@@ -372,22 +367,23 @@ bool FtpNegotiationCommand::sendSize() {
   return false;
 }
 
-bool FtpNegotiationCommand::onFileSizeDetermined(uint64_t totalLength)
+bool FtpNegotiationCommand::onFileSizeDetermined(int64_t totalLength)
 {
   getFileEntry()->setLength(totalLength);
   if(getFileEntry()->getPath().empty()) {
     getFileEntry()->setPath
-      (util::applyDir
-       (getDownloadContext()->getDir(),
-        util::fixTaintedBasename
-        (util::percentDecode(getRequest()->getFile()))));
+      (util::createSafePath
+       (getOption()->get(PREF_DIR),
+        util::percentDecode(getRequest()->getFile().begin(),
+                            getRequest()->getFile().end())));
   }
   getRequestGroup()->preDownloadProcessing();
   if(getDownloadEngine()->getRequestGroupMan()->
      isSameFileBeingDownloaded(getRequestGroup())) {
-    throw DOWNLOAD_FAILURE_EXCEPTION
-      (StringFormat(EX_DUPLICATE_FILE_DOWNLOAD,
-                    getRequestGroup()->getFirstFilePath().c_str()).str());
+    throw DOWNLOAD_FAILURE_EXCEPTION2
+      (fmt(EX_DUPLICATE_FILE_DOWNLOAD,
+           getRequestGroup()->getFirstFilePath().c_str()),
+       error_code::DUPLICATE_DOWNLOAD);
   }
   if(totalLength == 0) {
 
@@ -405,21 +401,32 @@ bool FtpNegotiationCommand::onFileSizeDetermined(uint64_t totalLength)
 
     if(getDownloadContext()->knowsTotalLength() &&
        getRequestGroup()->downloadFinishedByFileLength()) {
-      // TODO If metalink file does not contain size and it contains
-      // hash and file is not zero length, but remote server says the
-      // file size is 0, no hash check is performed in the current
-      // implementation. See also
+#ifdef ENABLE_MESSAGE_DIGEST
+      // TODO Known issue: if .aria2 file exists, it will not be
+      // deleted on successful verification, because .aria2 file is
+      // not loaded.  See also
       // HttpResponseCommand::handleOtherEncoding()
       getRequestGroup()->initPieceStorage();
-      getPieceStorage()->markAllPiecesDone();
-      getDownloadContext()->setChecksumVerified(true);
-      sequence_ = SEQ_DOWNLOAD_ALREADY_COMPLETED;
-      getLogger()->notice(MSG_DOWNLOAD_ALREADY_COMPLETED,
-                          util::itos(getRequestGroup()->getGID()).c_str(),
-                          getRequestGroup()->getFirstFilePath().c_str());
-
+      if(getDownloadContext()->isChecksumVerificationNeeded()) {
+        A2_LOG_DEBUG("Zero length file exists. Verify checksum.");
+        SharedHandle<ChecksumCheckIntegrityEntry> entry
+          (new ChecksumCheckIntegrityEntry(getRequestGroup()));
+        entry->initValidator();
+        getPieceStorage()->getDiskAdaptor()->openExistingFile();
+        getDownloadEngine()->getCheckIntegrityMan()->pushEntry(entry);
+        sequence_ = SEQ_EXIT;
+      } else
+#endif // ENABLE_MESSAGE_DIGEST
+        {
+          getPieceStorage()->markAllPiecesDone();
+          getDownloadContext()->setChecksumVerified(true);
+          sequence_ = SEQ_DOWNLOAD_ALREADY_COMPLETED;
+          A2_LOG_NOTICE
+            (fmt(MSG_DOWNLOAD_ALREADY_COMPLETED,
+                 getRequestGroup()->getGID(),
+                 getRequestGroup()->getFirstFilePath().c_str()));
+        }
       poolConnection();
-
       return false;
     }
 
@@ -428,8 +435,25 @@ bool FtpNegotiationCommand::onFileSizeDetermined(uint64_t totalLength)
     getPieceStorage()->getDiskAdaptor()->initAndOpenFile();
 
     if(getDownloadContext()->knowsTotalLength()) {
-      sequence_ = SEQ_DOWNLOAD_ALREADY_COMPLETED;
-      getPieceStorage()->markAllPiecesDone();
+      A2_LOG_DEBUG("File length becomes zero and it means download completed.");
+#ifdef ENABLE_MESSAGE_DIGEST
+      // TODO Known issue: if .aria2 file exists, it will not be
+      // deleted on successful verification, because .aria2 file is
+      // not loaded.  See also
+      // HttpResponseCommand::handleOtherEncoding()
+      if(getDownloadContext()->isChecksumVerificationNeeded()) {
+        A2_LOG_DEBUG("Verify checksum for zero-length file");
+        SharedHandle<ChecksumCheckIntegrityEntry> entry
+          (new ChecksumCheckIntegrityEntry(getRequestGroup()));
+        entry->initValidator();
+        getDownloadEngine()->getCheckIntegrityMan()->pushEntry(entry);
+        sequence_ = SEQ_EXIT;
+      } else
+#endif // ENABLE_MESSAGE_DIGEST
+        {
+          sequence_ = SEQ_DOWNLOAD_ALREADY_COMPLETED;
+          getPieceStorage()->markAllPiecesDone();
+        }
       poolConnection();
       return false;
     }
@@ -439,12 +463,10 @@ bool FtpNegotiationCommand::onFileSizeDetermined(uint64_t totalLength)
     getSegmentMan()->getSegmentWithIndex(getCuid(), 0);
     return true;
   } else {
-    getRequestGroup()->adjustFilename
-      (SharedHandle<BtProgressInfoFile>
-       (new DefaultBtProgressInfoFile
-        (getDownloadContext(),
-         SharedHandle<PieceStorage>(),
-         getOption().get())));
+    SharedHandle<BtProgressInfoFile> progressInfoFile
+      (new DefaultBtProgressInfoFile
+       (getDownloadContext(), SharedHandle<PieceStorage>(), getOption().get()));
+    getRequestGroup()->adjustFilename(progressInfoFile);
     getRequestGroup()->initPieceStorage();
 
     if(getOption()->getAsBool(PREF_DRY_RUN)) {
@@ -454,7 +476,7 @@ bool FtpNegotiationCommand::onFileSizeDetermined(uint64_t totalLength)
 
     SharedHandle<CheckIntegrityEntry> checkIntegrityEntry =
       getRequestGroup()->createCheckIntegrityEntry();
-    if(checkIntegrityEntry.isNull()) {
+    if(!checkIntegrityEntry) {
       sequence_ = SEQ_DOWNLOAD_ALREADY_COMPLETED;
       poolConnection();
       return false;
@@ -473,19 +495,17 @@ bool FtpNegotiationCommand::onFileSizeDetermined(uint64_t totalLength)
 }
 
 bool FtpNegotiationCommand::recvSize() {
-  uint64_t size = 0;
-  unsigned int status = ftp_->receiveSizeResponse(size);
+  int64_t size = 0;
+  int status = ftp_->receiveSizeResponse(size);
   if(status == 0) {
     return false;
   }
   if(status == 213) {
-
-    if(size > INT64_MAX) {
-      throw DL_ABORT_EX
-        (StringFormat(EX_TOO_LARGE_FILE,
-                      util::uitos(size, true).c_str()).str());
+    if(size > std::numeric_limits<off_t>::max()) {
+      throw DL_ABORT_EX2(fmt(EX_TOO_LARGE_FILE, size),
+                         error_code::FTP_PROTOCOL_ERROR);
     }
-    if(getPieceStorage().isNull()) {
+    if(!getPieceStorage()) {
 
       sequence_ = SEQ_FILE_PREPARATION;
       return onFileSizeDetermined(size);
@@ -495,14 +515,12 @@ bool FtpNegotiationCommand::recvSize() {
     }
 
   } else {
-    if(getLogger()->info()) {
-      getLogger()->info("CUID#%s - The remote FTP Server doesn't recognize SIZE"
-                        " command. Continue.", util::itos(getCuid()).c_str());
-    }
+    A2_LOG_INFO(fmt("CUID#%" PRId64 " - The remote FTP Server doesn't recognize SIZE"
+                    " command. Continue.", getCuid()));
     // Even if one of the other servers waiting in the queue supports SIZE
     // command, resuming and segmented downloading are disabled when the first
     // contacted FTP server doesn't support it.
-    if(getPieceStorage().isNull()) {
+    if(!getPieceStorage()) {
       getDownloadContext()->markTotalLengthIsUnknown();
       return onFileSizeDetermined(0);
 
@@ -557,7 +575,7 @@ bool FtpNegotiationCommand::sendEprt() {
 }
 
 bool FtpNegotiationCommand::recvEprt() {
-  unsigned int status = ftp_->receiveResponse();
+  int status = ftp_->receiveResponse();
   if(status == 0) {
     return false;
   }
@@ -580,12 +598,13 @@ bool FtpNegotiationCommand::sendPort() {
 }
 
 bool FtpNegotiationCommand::recvPort() {
-  unsigned int status = ftp_->receiveResponse();
+  int status = ftp_->receiveResponse();
   if(status == 0) {
     return false;
   }
   if(status != 200) {
-    throw DL_ABORT_EX(StringFormat(EX_BAD_STATUS, status).str());
+    throw DL_ABORT_EX2(fmt(EX_BAD_STATUS, status),
+                       error_code::FTP_PROTOCOL_ERROR);
   }
   sequence_ = SEQ_SEND_REST;
   return true;
@@ -613,15 +632,12 @@ bool FtpNegotiationCommand::sendEpsv() {
 
 bool FtpNegotiationCommand::recvEpsv() {
   uint16_t port;
-  unsigned int status = ftp_->receiveEpsvResponse(port);
+  int status = ftp_->receiveEpsvResponse(port);
   if(status == 0) {
     return false;
   }
   if(status == 229) {
-    std::pair<std::string, uint16_t> peerInfo;
-    getSocket()->getPeerInfo(peerInfo);
-    peerInfo.second = port;
-    dataConnAddr_ = peerInfo;
+    pasvPort_ = port;
     return preparePasvConnect();
   } else {
     sequence_ = SEQ_SEND_PASV;
@@ -641,33 +657,32 @@ bool FtpNegotiationCommand::sendPasv() {
 
 bool FtpNegotiationCommand::recvPasv() {
   std::pair<std::string, uint16_t> dest;
-  unsigned int status = ftp_->receivePasvResponse(dest);
+  int status = ftp_->receivePasvResponse(dest);
   if(status == 0) {
     return false;
   }
   if(status != 227) {
-    throw DL_ABORT_EX(StringFormat(EX_BAD_STATUS, status).str());
+    throw DL_ABORT_EX2(fmt(EX_BAD_STATUS, status),
+                       error_code::FTP_PROTOCOL_ERROR);
   }
-  dataConnAddr_ = dest;
-
+  pasvPort_ = dest.second;;
   return preparePasvConnect();
 }
 
 bool FtpNegotiationCommand::preparePasvConnect() {
-  // TODO Should we check to see that dataConnAddr_.first is not in
-  // noProxy list?
   if(isProxyDefined()) {
     sequence_ = SEQ_RESOLVE_PROXY;
     return true;
   } else {
+    std::pair<std::string, uint16_t> dataAddr;
+    getSocket()->getPeerInfo(dataAddr);
     // make a data connection to the server.
-    if(getLogger()->info()) {
-      getLogger()->info(MSG_CONNECTING_TO_SERVER, util::itos(getCuid()).c_str(),
-                        dataConnAddr_.first.c_str(),
-                        dataConnAddr_.second);
-    }
+    A2_LOG_INFO(fmt(MSG_CONNECTING_TO_SERVER,
+                    getCuid(),
+                    dataAddr.first.c_str(),
+                    pasvPort_));
     dataSocket_.reset(new SocketCore());
-    dataSocket_->establishConnection(dataConnAddr_.first, dataConnAddr_.second);
+    dataSocket_->establishConnection(dataAddr.first, pasvPort_);
     disableReadCheckSocket();
     setWriteCheckSocket(dataSocket_);
     sequence_ = SEQ_SEND_REST_PASV;
@@ -684,15 +699,16 @@ bool FtpNegotiationCommand::resolveProxy()
   if(proxyAddr_.empty()) {
     return false;
   }
-  if(getLogger()->info()) {
-    getLogger()->info(MSG_CONNECTING_TO_SERVER, util::itos(getCuid()).c_str(),
-                      proxyAddr_.c_str(), proxyReq->getPort());
-  }
-  dataSocket_.reset(new SocketCore());                  
+  A2_LOG_INFO(fmt(MSG_CONNECTING_TO_SERVER,
+                  getCuid(),
+                  proxyAddr_.c_str(), proxyReq->getPort()));
+  dataSocket_.reset(new SocketCore());
   dataSocket_->establishConnection(proxyAddr_, proxyReq->getPort());
   disableReadCheckSocket();
   setWriteCheckSocket(dataSocket_);
-  http_.reset(new HttpConnection(getCuid(), dataSocket_));
+  SharedHandle<SocketRecvBuffer> socketRecvBuffer
+    (new SocketRecvBuffer(dataSocket_));
+  http_.reset(new HttpConnection(getCuid(), dataSocket_, socketRecvBuffer));
   sequence_ = SEQ_SEND_TUNNEL_REQUEST;
   return false;
 }
@@ -712,31 +728,34 @@ bool FtpNegotiationCommand::sendTunnelRequest()
           getDownloadEngine()->removeCachedIPAddress(proxyReq->getHost(),
                                                      proxyReq->getPort());
           throw DL_RETRY_EX
-            (StringFormat(MSG_ESTABLISHING_CONNECTION_FAILED,
-                          error.c_str()).str());
+            (fmt(MSG_ESTABLISHING_CONNECTION_FAILED,
+                 error.c_str()));
         } else {
-          if(getLogger()->info()) {
-            getLogger()->info(MSG_CONNECT_FAILED_AND_RETRY,
-                              util::itos(getCuid()).c_str(),
-                              proxyAddr_.c_str(), proxyReq->getPort());
-          }
+          A2_LOG_INFO(fmt(MSG_CONNECT_FAILED_AND_RETRY,
+                          getCuid(),
+                          proxyAddr_.c_str(), proxyReq->getPort()));
           proxyAddr_ = nextProxyAddr;
-          if(getLogger()->info()) {
-            getLogger()->info(MSG_CONNECTING_TO_SERVER,
-                              util::itos(getCuid()).c_str(),
-                              proxyAddr_.c_str(), proxyReq->getPort());
-          }
+          A2_LOG_INFO(fmt(MSG_CONNECTING_TO_SERVER,
+                          getCuid(),
+                          proxyAddr_.c_str(), proxyReq->getPort()));
           dataSocket_->establishConnection(proxyAddr_, proxyReq->getPort());
           return false;
         }
       }
-    }      
+    }
     SharedHandle<HttpRequest> httpRequest(new HttpRequest());
     httpRequest->setUserAgent(getOption()->get(PREF_USER_AGENT));
     SharedHandle<Request> req(new Request());
     // Construct fake URI in order to use HttpRequest
-    req->setUri(strconcat("ftp://", dataConnAddr_.first,
-                          A2STR::COLON_C, util::uitos(dataConnAddr_.second)));
+    std::pair<std::string, uint16_t> dataAddr;
+    uri::UriStruct us;
+    us.protocol = "ftp";
+    us.host = getRequest()->getHost();
+    us.port = pasvPort_;
+    us.ipv6LiteralAddress = getRequest()->isIPv6LiteralAddress();
+    if(!req->setUri(uri::construct(us))) {
+      throw DL_RETRY_EX("Something wrong with FTP URI");
+    }
     httpRequest->setRequest(req);
     httpRequest->setProxyRequest(createProxyRequest());
     http_->sendProxyRequest(httpRequest);
@@ -757,10 +776,10 @@ bool FtpNegotiationCommand::sendTunnelRequest()
 bool FtpNegotiationCommand::recvTunnelResponse()
 {
   SharedHandle<HttpResponse> httpResponse = http_->receiveResponse();
-  if(httpResponse.isNull()) {
+  if(!httpResponse) {
     return false;
   }
-  if(httpResponse->getResponseStatus() != HttpHeader::S200) {
+  if(httpResponse->getStatusCode() != 200) {
     throw DL_RETRY_EX(EX_PROXY_CONNECTION_FAILED);
   }
   sequence_ = SEQ_SEND_REST_PASV;
@@ -772,8 +791,9 @@ bool FtpNegotiationCommand::sendRestPasv(const SharedHandle<Segment>& segment) {
   // Check connection is made properly
   if(dataSocket_->isReadable(0)) {
     std::string error = dataSocket_->getSocketError();
-    throw DL_ABORT_EX
-      (StringFormat(MSG_ESTABLISHING_CONNECTION_FAILED, error.c_str()).str());
+    throw DL_ABORT_EX2
+      (fmt(MSG_ESTABLISHING_CONNECTION_FAILED, error.c_str()),
+       error_code::FTP_PROTOCOL_ERROR);
   }
   setReadCheckSocket(getSocket());
   disableWriteCheckSocket();
@@ -791,16 +811,16 @@ bool FtpNegotiationCommand::sendRest(const SharedHandle<Segment>& segment) {
 }
 
 bool FtpNegotiationCommand::recvRest(const SharedHandle<Segment>& segment) {
-  unsigned int status = ftp_->receiveResponse();
+  int status = ftp_->receiveResponse();
   if(status == 0) {
     return false;
   }
   // If we recieve negative response and requested file position is not 0,
   // then throw exception here.
   if(status != 350) {
-    if(!segment.isNull() && segment->getPositionToWrite() != 0) {
+    if(segment && segment->getPositionToWrite() != 0) {
       throw DL_ABORT_EX2("FTP server doesn't support resuming.",
-                         downloadresultcode::CANNOT_RESUME);
+                         error_code::CANNOT_RESUME);
     }
   }
   sequence_ = SEQ_SEND_RETR;
@@ -818,7 +838,7 @@ bool FtpNegotiationCommand::sendRetr() {
 }
 
 bool FtpNegotiationCommand::recvRetr() {
-  unsigned int status = ftp_->receiveResponse();
+  int status = ftp_->receiveResponse();
   if(status == 0) {
     return false;
   }
@@ -826,9 +846,10 @@ bool FtpNegotiationCommand::recvRetr() {
     getRequestGroup()->increaseAndValidateFileNotFoundCount();
     if (status == 550)
       throw DL_ABORT_EX2(MSG_RESOURCE_NOT_FOUND,
-                         downloadresultcode::RESOURCE_NOT_FOUND);
+                         error_code::RESOURCE_NOT_FOUND);
     else
-      throw DL_ABORT_EX(StringFormat(EX_BAD_STATUS, status).str());
+      throw DL_ABORT_EX2(fmt(EX_BAD_STATUS, status),
+                         error_code::FTP_PROTOCOL_ERROR);
   }
   if(getOption()->getAsBool(PREF_FTP_PASV)) {
     sequence_ = SEQ_NEGOTIATION_COMPLETED;
@@ -845,8 +866,7 @@ bool FtpNegotiationCommand::waitConnection()
 {
   disableReadCheckSocket();
   setReadCheckSocket(getSocket());
-  dataSocket_.reset(serverSocket_->acceptConnection());
-  dataSocket_->setNonBlockingMode();
+  dataSocket_ = serverSocket_->acceptConnection();
   sequence_ = SEQ_NEGOTIATION_COMPLETED;
   return false;
 }
@@ -938,10 +958,10 @@ bool FtpNegotiationCommand::processSequence
 void FtpNegotiationCommand::poolConnection() const
 {
   if(getOption()->getAsBool(PREF_FTP_REUSE_CONNECTION)) {
-    std::map<std::string, std::string> options;
-    options["baseWorkingDir"] = ftp_->getBaseWorkingDir();
+    // Store ftp_->getBaseWorkingDir() as options
     getDownloadEngine()->poolSocket(getRequest(), ftp_->getUser(),
-                                    createProxyRequest(), getSocket(), options);
+                                    createProxyRequest(), getSocket(),
+                                    ftp_->getBaseWorkingDir());
   }
 }
 
