@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -38,24 +38,33 @@
 #include "PieceStorage.h"
 #include "RequestGroup.h"
 
-HaveEraseCommand::HaveEraseCommand(int32_t cuid, DownloadEngine* e, int32_t interval)
-  :TimeBasedCommand(cuid, e, interval) {}
+namespace aria2 {
+
+HaveEraseCommand::HaveEraseCommand(cuid_t cuid, DownloadEngine* e, time_t interval)
+  :TimeBasedCommand(cuid, e, interval, true) {}
 
 HaveEraseCommand::~HaveEraseCommand() {}
 
 void HaveEraseCommand::preProcess()
 {
-  if(_e->_requestGroupMan->downloadFinished() || _e->isHaltRequested()) {
-    _exit = true;
+  if(getDownloadEngine()->getRequestGroupMan()->downloadFinished() ||
+     getDownloadEngine()->isHaltRequested()) {
+    enableExit();
   }
 }
 
 void HaveEraseCommand::process()
 {
-  for(int32_t i = 0; i < _e->_requestGroupMan->countRequestGroup(); ++i) {
-    PieceStorageHandle ps = _e->_requestGroupMan->getRequestGroup(i)->getPieceStorage();
-    if(!ps.isNull()) {
+  size_t numLoop =
+    getDownloadEngine()->getRequestGroupMan()->countRequestGroup();
+  for(size_t i = 0; i < numLoop; ++i) {
+    SharedHandle<PieceStorage> ps =
+      getDownloadEngine()->getRequestGroupMan()->getRequestGroup(i)->
+      getPieceStorage();
+    if(ps) {
       ps->removeAdvertisedPiece(5);
     }
   }
 }
+
+} // namespace aria2
