@@ -101,7 +101,7 @@ bool DiskWriterEntry::fileExists()
   return fileEntry_->exists();
 }
 
-uint64_t DiskWriterEntry::size() const
+int64_t DiskWriterEntry::size() const
 {
   return File(getFilePath()).size();
 }
@@ -132,7 +132,7 @@ SharedHandle<DiskWriterEntry> createDiskWriterEntry
   SharedHandle<DiskWriterEntry> entry(new DiskWriterEntry(fileEntry));
   entry->needsFileAllocation(needsFileAllocation);
   return entry;
-} 
+}
 } // namespace
 
 void MultiDiskAdaptor::resetDiskWriterEntries()
@@ -162,15 +162,14 @@ void MultiDiskAdaptor::resetDiskWriterEntries()
         ++itr;
         continue;
       }
-      off_t pieceStartOffset =
+      int64_t pieceStartOffset =
         (fileEntry->getOffset()/pieceLength_)*pieceLength_;
       if(itr != diskWriterEntries_.begin()) {
         for(std::vector<SharedHandle<DiskWriterEntry> >::const_iterator i =
               itr-1; true; --i) {
           const SharedHandle<FileEntry>& fileEntry = (*i)->getFileEntry();
           if(pieceStartOffset <= fileEntry->getOffset() ||
-             (uint64_t)pieceStartOffset <
-             fileEntry->getOffset()+fileEntry->getLength()) {
+             pieceStartOffset < fileEntry->getLastOffset()) {
             (*i)->needsFileAllocation(true);
           } else {
             break;
@@ -182,13 +181,13 @@ void MultiDiskAdaptor::resetDiskWriterEntries()
       }
 
       if(fileEntry->getLength() > 0) {
-        off_t lastPieceStartOffset =
+        int64_t lastPieceStartOffset =
           (fileEntry->getOffset()+fileEntry->getLength()-1)/
           pieceLength_*pieceLength_;
         A2_LOG_DEBUG(fmt("Checking adjacent backward file to %s"
-                         " whose lastPieceStartOffset+pieceLength_=%lld",
+                         " whose lastPieceStartOffset+pieceLength_=%" PRId64 "",
                          fileEntry->getPath().c_str(),
-                         static_cast<long long int>
+                         static_cast<int64_t>
                          (lastPieceStartOffset+pieceLength_)));
         ++itr;
         // adjacent backward files are not needed to be allocated. They
@@ -197,12 +196,11 @@ void MultiDiskAdaptor::resetDiskWriterEntries()
               (!(*itr)->getFileEntry()->isRequested() ||
                (*itr)->getFileEntry()->getLength() == 0); ++itr) {
           A2_LOG_DEBUG
-            (fmt("file=%s, offset=%lld",
+            (fmt("file=%s, offset=%" PRId64 "",
                  (*itr)->getFileEntry()->getPath().c_str(),
-                 static_cast<long long int>
-                 ((*itr)->getFileEntry()->getOffset())));
+                 (*itr)->getFileEntry()->getOffset()));
           if((*itr)->getFileEntry()->getOffset() <
-             static_cast<off_t>(lastPieceStartOffset+pieceLength_)) {
+             lastPieceStartOffset+pieceLength_) {
             A2_LOG_DEBUG
               (fmt("%s needs diskwriter",
                    (*itr)->getFileEntry()->getPath().c_str()));
@@ -231,6 +229,8 @@ void MultiDiskAdaptor::resetDiskWriterEntries()
       if(readOnly_) {
         (*i)->getDiskWriter()->enableReadOnly();
       }
+      // TODO mmap is not enabled at this moment. Call enableMmap()
+      // after this function call.
     }
   }
 }
@@ -241,11 +241,11 @@ void MultiDiskAdaptor::openIfNot
   if(!entry->isOpen()) {
     //     A2_LOG_DEBUG(fmt("DiskWriterEntry: Cache MISS. offset=%s",
     //            util::itos(entry->getFileEntry()->getOffset()).c_str()));
- 
-    size_t numOpened = openedDiskWriterEntries_.size();
+
+    int numOpened = openedDiskWriterEntries_.size();
     (entry.get()->*open)();
     if(numOpened >= maxOpenFiles_) {
-      // Cache is full. 
+      // Cache is full.
       // Choose one DiskWriterEntry randomly and close it.
       size_t index =
         SimpleRandomizer::getInstance()->getRandomNumber(numOpened);
@@ -256,7 +256,7 @@ void MultiDiskAdaptor::openIfNot
       (*i) = entry;
     } else {
       openedDiskWriterEntries_.push_back(entry);
-    } 
+    }
   } else {
     //     A2_LOG_DEBUG(fmt("DiskWriterEntry: Cache HIT. offset=%s",
     //            util::itos(entry->getFileEntry()->getOffset()).c_str()));
@@ -303,32 +303,29 @@ void MultiDiskAdaptor::closeFile()
 }
 
 namespace {
-bool isInRange(const DiskWriterEntryHandle entry, off_t offset)
+bool isInRange(const SharedHandle<DiskWriterEntry> entry, int64_t offset)
 {
   return entry->getFileEntry()->getOffset() <= offset &&
-    (uint64_t)offset <
-    entry->getFileEntry()->getOffset()+entry->getFileEntry()->getLength();
+    offset < entry->getFileEntry()->getLastOffset();
 }
 } // namespace
 
 namespace {
-size_t calculateLength(const DiskWriterEntryHandle entry,
-                       off_t fileOffset, size_t rem)
+ssize_t calculateLength(const SharedHandle<DiskWriterEntry> entry,
+                        int64_t fileOffset, ssize_t rem)
 {
-  size_t length;
-  if(entry->getFileEntry()->getLength() < (uint64_t)fileOffset+rem) {
-    length = entry->getFileEntry()->getLength()-fileOffset;
+  if(entry->getFileEntry()->getLength() < fileOffset+rem) {
+    return entry->getFileEntry()->getLength()-fileOffset;
   } else {
-    length = rem;
+    return rem;
   }
-  return length;
 }
 } // namespace
 
 namespace {
 class OffsetCompare {
 public:
-  bool operator()(off_t offset, const SharedHandle<DiskWriterEntry>& dwe)
+  bool operator()(int64_t offset, const SharedHandle<DiskWriterEntry>& dwe)
   {
     return offset < dwe->getFileEntry()->getOffset();
   }
@@ -337,7 +334,7 @@ public:
 
 namespace {
 DiskWriterEntries::const_iterator findFirstDiskWriterEntry
-(const DiskWriterEntries& diskWriterEntries, off_t offset)
+(const DiskWriterEntries& diskWriterEntries, int64_t offset)
 {
   DiskWriterEntries::const_iterator first =
     std::upper_bound(diskWriterEntries.begin(), diskWriterEntries.end(),
@@ -348,8 +345,7 @@ DiskWriterEntries::const_iterator findFirstDiskWriterEntry
   // In case when offset is out-of-range
   if(!isInRange(*first, offset)) {
     throw DL_ABORT_EX
-      (fmt(EX_FILE_OFFSET_OUT_OF_RANGE,
-           util::itos(offset, true).c_str()));
+      (fmt(EX_FILE_OFFSET_OUT_OF_RANGE, static_cast<int64_t>(offset)));
   }
   return first;
 }
@@ -357,26 +353,26 @@ DiskWriterEntries::const_iterator findFirstDiskWriterEntry
 
 namespace {
 void throwOnDiskWriterNotOpened(const SharedHandle<DiskWriterEntry>& e,
-                                off_t offset)
+                                int64_t offset)
 {
   throw DL_ABORT_EX
-    (fmt("DiskWriter for offset=%s, filename=%s is not opened.",
-         util::itos(offset).c_str(),
-         e->getFilePath().c_str()));  
+    (fmt("DiskWriter for offset=%" PRId64 ", filename=%s is not opened.",
+         static_cast<int64_t>(offset),
+         e->getFilePath().c_str()));
 }
 } // namespace
 
 void MultiDiskAdaptor::writeData(const unsigned char* data, size_t len,
-                                 off_t offset)
+                                 int64_t offset)
 {
   DiskWriterEntries::const_iterator first =
     findFirstDiskWriterEntry(diskWriterEntries_, offset);
 
-  size_t rem = len;
-  off_t fileOffset = offset-(*first)->getFileEntry()->getOffset();
+  ssize_t rem = len;
+  int64_t fileOffset = offset-(*first)->getFileEntry()->getOffset();
   for(DiskWriterEntries::const_iterator i = first,
         eoi = diskWriterEntries_.end(); i != eoi; ++i) {
-    size_t writeLength = calculateLength(*i, fileOffset, rem);
+    ssize_t writeLength = calculateLength(*i, fileOffset, rem);
 
     openIfNot(*i, &DiskWriterEntry::openFile);
 
@@ -394,17 +390,17 @@ void MultiDiskAdaptor::writeData(const unsigned char* data, size_t len,
 }
 
 ssize_t MultiDiskAdaptor::readData
-(unsigned char* data, size_t len, off_t offset)
+(unsigned char* data, size_t len, int64_t offset)
 {
   DiskWriterEntries::const_iterator first =
     findFirstDiskWriterEntry(diskWriterEntries_, offset);
 
-  size_t rem = len;
-  size_t totalReadLength = 0;
-  off_t fileOffset = offset-(*first)->getFileEntry()->getOffset();
+  ssize_t rem = len;
+  ssize_t totalReadLength = 0;
+  int64_t fileOffset = offset-(*first)->getFileEntry()->getOffset();
   for(DiskWriterEntries::const_iterator i = first,
         eoi = diskWriterEntries_.end(); i != eoi; ++i) {
-    size_t readLength = calculateLength(*i, fileOffset, rem);
+    ssize_t readLength = calculateLength(*i, fileOffset, rem);
 
     openIfNot(*i, &DiskWriterEntry::openFile);
 
@@ -430,9 +426,9 @@ bool MultiDiskAdaptor::fileExists()
     getFileEntries().end();
 }
 
-uint64_t MultiDiskAdaptor::size()
+int64_t MultiDiskAdaptor::size()
 {
-  uint64_t size = 0;
+  int64_t size = 0;
   for(std::vector<SharedHandle<FileEntry> >::const_iterator i =
         getFileEntries().begin(), eoi = getFileEntries().end(); i != eoi; ++i) {
     size += File((*i)->getPath()).size();
@@ -456,21 +452,33 @@ void MultiDiskAdaptor::disableReadOnly()
   readOnly_ = false;
 }
 
+void MultiDiskAdaptor::enableMmap()
+{
+  for(std::vector<SharedHandle<DiskWriterEntry> >::const_iterator i =
+        diskWriterEntries_.begin(), eoi = diskWriterEntries_.end();
+      i != eoi; ++i) {
+    const SharedHandle<DiskWriter>& dw = (*i)->getDiskWriter();
+    if(dw) {
+      dw->enableMmap();
+    }
+  }
+}
+
 void MultiDiskAdaptor::cutTrailingGarbage()
 {
   for(std::vector<SharedHandle<DiskWriterEntry> >::const_iterator i =
         diskWriterEntries_.begin(), eoi = diskWriterEntries_.end();
       i != eoi; ++i) {
-    uint64_t length = (*i)->getFileEntry()->getLength();
+    int64_t length = (*i)->getFileEntry()->getLength();
     if(File((*i)->getFilePath()).size() > length) {
-      // We need open file before calling DiskWriter::truncate(uint64_t)
+      // We need open file before calling DiskWriter::truncate(int64_t)
       openIfNot(*i, &DiskWriterEntry::openFile);
       (*i)->getDiskWriter()->truncate(length);
     }
   }
 }
 
-void MultiDiskAdaptor::setMaxOpenFiles(size_t maxOpenFiles)
+void MultiDiskAdaptor::setMaxOpenFiles(int maxOpenFiles)
 {
   maxOpenFiles_ = maxOpenFiles;
 }
