@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_NULL_PROGRESS_INFO_FILE_H_
-#define _D_NULL_PROGRESS_INFO_FILE_H_
+#ifndef D_NULL_PROGRESS_INFO_FILE_H
+#define D_NULL_PROGRESS_INFO_FILE_H
 
 #include "BtProgressInfoFile.h"
 #include "A2STR.h"
@@ -60,8 +60,6 @@ public:
   virtual void updateFilename() {}
 };
 
-typedef SharedHandle<NullProgressInfoFile> NullProgressInfoFileHandle;
-
 } // namespace aria2
 
-#endif // _D_NULL_PROGRESS_INFO_FILE_H_
+#endif // D_NULL_PROGRESS_INFO_FILE_H
