@@ -50,6 +50,7 @@ namespace aria2 {
 Peer::Peer(std::string ipaddr, uint16_t port, bool incoming):
   ipaddr_(ipaddr),
   port_(port),
+  id_(fmt("%s(%u)", ipaddr_.c_str(), port_)),
   firstContactTime_(global::wallclock()),
   badConditionStartTime_(0),
   seeder_(false),
@@ -60,8 +61,6 @@ Peer::Peer(std::string ipaddr, uint16_t port, bool incoming):
 {
   memset(peerId_, 0, PEER_ID_LENGTH);
   resetStatus();
-  id_ = ipaddr_;
-  strappend(id_, A2STR::COLON_C, util::uitos(port_));
 }
 
 Peer::~Peer()
@@ -74,15 +73,15 @@ void Peer::usedBy(cuid_t cuid)
   cuid_ = cuid;
 }
 
-void Peer::allocateSessionResource(size_t pieceLength, uint64_t totalLength)
+void Peer::allocateSessionResource(int32_t pieceLength, int64_t totalLength)
 {
   delete res_;
   res_ = new PeerSessionResource(pieceLength, totalLength);
-  res_->getPeerStat().downloadStart();
+  res_->getNetStat().downloadStart();
   updateSeeder();
 }
 
-void Peer::reconfigureSessionResource(size_t pieceLength, uint64_t totalLength)
+void Peer::reconfigureSessionResource(int32_t pieceLength, int64_t totalLength)
 {
   assert(res_);
   res_->reconfigure(pieceLength, totalLength);
@@ -153,7 +152,7 @@ void Peer::peerInterested(bool b)
   assert(res_);
   res_->peerInterested(b);
 }
-  
+
 // this peer should be choked
 bool Peer::chokingRequired() const
 {
@@ -193,13 +192,13 @@ void Peer::snubbing(bool b)
   res_->snubbing(b);
 }
 
-void Peer::updateUploadLength(size_t bytes)
+void Peer::updateUploadLength(int32_t bytes)
 {
   assert(res_);
   res_->updateUploadLength(bytes);
 }
 
-void Peer::updateDownloadLength(size_t bytes)
+void Peer::updateDownloadLength(int32_t bytes)
 {
   assert(res_);
   res_->updateDownloadLength(bytes);
@@ -217,25 +216,25 @@ void Peer::updateBitfield(size_t index, int operation) {
   updateSeeder();
 }
 
-unsigned int Peer::calculateUploadSpeed()
+int Peer::calculateUploadSpeed()
 {
   assert(res_);
-  return res_->getPeerStat().calculateUploadSpeed();
+  return res_->getNetStat().calculateUploadSpeed();
 }
 
-unsigned int Peer::calculateDownloadSpeed()
+int Peer::calculateDownloadSpeed()
 {
   assert(res_);
-  return res_->getPeerStat().calculateDownloadSpeed();
+  return res_->getNetStat().calculateDownloadSpeed();
 }
 
-uint64_t Peer::getSessionUploadLength() const
+int64_t Peer::getSessionUploadLength() const
 {
   assert(res_);
   return res_->uploadLength();
 }
 
-uint64_t Peer::getSessionDownloadLength() const
+int64_t Peer::getSessionDownloadLength() const
 {
   assert(res_);
   return res_->downloadLength();
@@ -288,7 +287,7 @@ size_t Peer::countPeerAllowedIndexSet() const
   return res_->peerAllowedIndexSet().size();
 }
 
-const std::vector<size_t>& Peer::getPeerAllowedIndexSet() const
+const std::set<size_t>& Peer::getPeerAllowedIndexSet() const
 {
   assert(res_);
   return res_->peerAllowedIndexSet();
@@ -335,22 +334,22 @@ bool Peer::isGood() const
     difference(global::wallclock()) >= BAD_CONDITION_INTERVAL;
 }
 
-uint8_t Peer::getExtensionMessageID(const std::string& name) const
+uint8_t Peer::getExtensionMessageID(int key) const
 {
   assert(res_);
-  return res_->getExtensionMessageID(name);
+  return res_->getExtensionMessageID(key);
 }
 
-std::string Peer::getExtensionName(uint8_t id) const
+const char* Peer::getExtensionName(uint8_t id) const
 {
   assert(res_);
   return res_->getExtensionName(id);
 }
 
-void Peer::setExtension(const std::string& name, uint8_t id)
+void Peer::setExtension(int key, uint8_t id)
 {
   assert(res_);
-  res_->addExtension(name, id);
+  res_->addExtension(key, id);
 }
 
 void Peer::setExtendedMessagingEnabled(bool enabled)
@@ -389,7 +388,7 @@ const Timer& Peer::getLastAmUnchoking() const
   return res_->getLastAmUnchoking();
 }
 
-uint64_t Peer::getCompletedLength() const
+int64_t Peer::getCompletedLength() const
 {
   assert(res_);
   return res_->getCompletedLength();
