@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_PEER_ABSTRACT_COMMAND_H_
-#define _D_PEER_ABSTRACT_COMMAND_H_
+#ifndef D_PEER_ABSTRACT_COMMAND_H
+#define D_PEER_ABSTRACT_COMMAND_H
 
 #include "Command.h"
 #include "SharedHandle.h"
@@ -82,7 +82,7 @@ protected:
   virtual void onAbort() {};
   // This function is called when DownloadFailureException is caught right after
   // the invocation of onAbort().
-  virtual void onFailure() {};
+  virtual void onFailure(const Exception& err) {};
   virtual bool exitBeforeExecute() = 0;
   virtual bool executeInternal() = 0;
   void setReadCheckSocket(const SharedHandle<SocketCore>& socket);
@@ -105,4 +105,4 @@ public:
 
 } // namespace aria2
 
-#endif // _D_PEER_ABSTRACT_COMMAND_H_
+#endif // D_PEER_ABSTRACT_COMMAND_H
