@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_SEQUENTIAL_DISPATCHER_COMMAND_H_
-#define _D_SEQUENTIAL_DISPATCHER_COMMAND_H_
+#ifndef D_SEQUENTIAL_DISPATCHER_COMMAND_H
+#define D_SEQUENTIAL_DISPATCHER_COMMAND_H
 
 #include "Command.h"
 #include "SharedHandle.h"
@@ -64,7 +64,7 @@ public:
   {
     setStatusRealtime();
   }
-  
+
   virtual bool execute()
   {
     if(e_->getRequestGroupMan()->downloadFinished() || e_->isHaltRequested()) {
@@ -86,4 +86,4 @@ protected:
 
 } // namespace aria2
 
-#endif // _D_SEQUENTIAL_DISPATCHER_COMMAND_H_
+#endif // D_SEQUENTIAL_DISPATCHER_COMMAND_H
