@@ -32,22 +32,32 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_SIMPLE_RANDOMIZER_H_
-#define _D_SIMPLE_RANDOMIZER_H_
+#ifndef D_SIMPLE_RANDOMIZER_H
+#define D_SIMPLE_RANDOMIZER_H
 
 #include "Randomizer.h"
 
+#ifdef __MINGW32__
+# include <wincrypt.h>
+#endif // __MINGW32__
+
+#include "SharedHandle.h"
+
 namespace aria2 {
 
 class SimpleRandomizer : public Randomizer {
 private:
   static SharedHandle<SimpleRandomizer> randomizer_;
 
+#ifdef __MINGW32__
+  HCRYPTPROV cryProvider_;
+#endif //__MINGW32__
+
   SimpleRandomizer();
 public:
-  
+
   static const SharedHandle<SimpleRandomizer>& getInstance();
-  
+
   static void init();
 
   virtual ~SimpleRandomizer();
@@ -66,4 +76,4 @@ public:
 
 } // namespace aria2
 
-#endif // _D_SIMPLE_RANDOMIZER_H_
+#endif // D_SIMPLE_RANDOMIZER_H
