@@ -8,6 +8,7 @@
 #include "Peer.h"
 #include "MockPieceStorage.h"
 #include "DlAbortEx.h"
+#include "FileEntry.h"
 
 namespace aria2 {
 
@@ -15,7 +16,7 @@ class BtHaveMessageTest:public CppUnit::TestFixture {
 
   CPPUNIT_TEST_SUITE(BtHaveMessageTest);
   CPPUNIT_TEST(testCreate);
-  CPPUNIT_TEST(testGetMessage);
+  CPPUNIT_TEST(testCreateMessage);
   CPPUNIT_TEST(testDoReceivedAction);
   CPPUNIT_TEST(testDoReceivedAction_goodByeSeeder);
   CPPUNIT_TEST(testToString);
@@ -27,7 +28,7 @@ public:
   }
 
   void testCreate();
-  void testGetMessage();
+  void testCreateMessage();
   void testDoReceivedAction();
   void testDoReceivedAction_goodByeSeeder();
   void testToString();
@@ -40,7 +41,7 @@ void BtHaveMessageTest::testCreate() {
   unsigned char msg[9];
   bittorrent::createPeerMessageString(msg, sizeof(msg), 5, 4);
   bittorrent::setIntParam(&msg[5], 12345);
-  SharedHandle<BtHaveMessage> pm = BtHaveMessage::create(&msg[4], 5);
+  SharedHandle<BtHaveMessage> pm(BtHaveMessage::create(&msg[4], 5));
   CPPUNIT_ASSERT_EQUAL((uint8_t)4, pm->getId());
   CPPUNIT_ASSERT_EQUAL((size_t)12345, pm->getIndex());
 
@@ -62,13 +63,15 @@ void BtHaveMessageTest::testCreate() {
   }
 }
 
-void BtHaveMessageTest::testGetMessage() {
+void BtHaveMessageTest::testCreateMessage() {
   BtHaveMessage msg;
   msg.setIndex(12345);
   unsigned char data[9];
   bittorrent::createPeerMessageString(data, sizeof(data), 5, 4);
   bittorrent::setIntParam(&data[5], 12345);
-  CPPUNIT_ASSERT(memcmp(msg.getMessage(), data, 9) == 0);
+  unsigned char* rawmsg = msg.createMessage();
+  CPPUNIT_ASSERT(memcmp(rawmsg, data, 9) == 0);
+  delete [] rawmsg;
 }
 
 void BtHaveMessageTest::testDoReceivedAction() {
@@ -119,7 +122,7 @@ void BtHaveMessageTest::testDoReceivedAction_goodByeSeeder()
     // success
   }
 }
-  
+
 void BtHaveMessageTest::testToString() {
   BtHaveMessage msg;
   msg.setIndex(1);
