@@ -16,15 +16,16 @@ class FeedbackURISelectorTest:public CppUnit::TestFixture {
   CPPUNIT_TEST_SUITE(FeedbackURISelectorTest);
   CPPUNIT_TEST(testSelect_withoutServerStat);
   CPPUNIT_TEST(testSelect);
+  CPPUNIT_TEST(testSelect_withUsedHosts);
   CPPUNIT_TEST(testSelect_skipErrorHost);
   CPPUNIT_TEST_SUITE_END();
 private:
-  FileEntry _fileEntry;
+  FileEntry fileEntry_;
 
   SharedHandle<ServerStatMan> ssm;
 
   SharedHandle<FeedbackURISelector> sel;
-  
+
 public:
   void setUp()
   {
@@ -33,10 +34,10 @@ public:
       "ftp://alpha/file",
       "http://bravo/file"
     };
-    std::deque<std::string> uris;
-    uris.assign(&urisSrc[0], &urisSrc[arrayLength(urisSrc)]);
-    
-    _fileEntry.setUris(uris);
+    std::vector<std::string> uris;
+    uris.assign(vbegin(urisSrc), vend(urisSrc));
+
+    fileEntry_.setUris(uris);
 
     ssm.reset(new ServerStatMan());
     sel.reset(new FeedbackURISelector(ssm));
@@ -45,9 +46,11 @@ public:
   void tearDown() {}
 
   void testSelect_withoutServerStat();
-  
+
   void testSelect();
 
+  void testSelect_withUsedHosts();
+
   void testSelect_skipErrorHost();
 };
 
@@ -56,10 +59,11 @@ CPPUNIT_TEST_SUITE_REGISTRATION(FeedbackURISelectorTest);
 
 void FeedbackURISelectorTest::testSelect_withoutServerStat()
 {
-  // Without ServerStat, selector returns first URI
-  std::string uri = sel->select(&_fileEntry);
+  std::vector<std::pair<size_t, std::string> > usedHosts;
+  // Without ServerStat and usedHosts, selector returns first URI
+  std::string uri = sel->select(&fileEntry_, usedHosts);
   CPPUNIT_ASSERT_EQUAL(std::string("http://alpha/file"), uri);
-  CPPUNIT_ASSERT_EQUAL((size_t)2, _fileEntry.getRemainingUris().size());
+  CPPUNIT_ASSERT_EQUAL((size_t)2, fileEntry_.getRemainingUris().size());
 }
 
 void FeedbackURISelectorTest::testSelect()
@@ -71,18 +75,38 @@ void FeedbackURISelectorTest::testSelect()
   SharedHandle<ServerStat> alphaHTTP(new ServerStat("alpha", "http"));
   alphaHTTP->updateDownloadSpeed(180000);
   alphaHTTP->setError();
+  std::vector<std::pair<size_t, std::string> > usedHosts;
 
   ssm->add(bravo);
   ssm->add(alphaFTP);
   ssm->add(alphaHTTP);
 
   CPPUNIT_ASSERT_EQUAL(std::string("http://bravo/file"),
-                       sel->select(&_fileEntry));
-  CPPUNIT_ASSERT_EQUAL((size_t)2, _fileEntry.getRemainingUris().size());
-  
+                       sel->select(&fileEntry_, usedHosts));
+  CPPUNIT_ASSERT_EQUAL((size_t)2, fileEntry_.getRemainingUris().size());
+
   CPPUNIT_ASSERT_EQUAL(std::string("ftp://alpha/file"),
-                       sel->select(&_fileEntry));
-  CPPUNIT_ASSERT_EQUAL((size_t)1, _fileEntry.getRemainingUris().size());
+                       sel->select(&fileEntry_, usedHosts));
+  CPPUNIT_ASSERT_EQUAL((size_t)1, fileEntry_.getRemainingUris().size());
+}
+
+void FeedbackURISelectorTest::testSelect_withUsedHosts()
+{
+  std::vector<std::pair<size_t, std::string> > usedHosts;
+  usedHosts.push_back(std::make_pair(1, "bravo"));
+  usedHosts.push_back(std::make_pair(2, "alpha"));
+
+  CPPUNIT_ASSERT_EQUAL(std::string("http://bravo/file"),
+                       sel->select(&fileEntry_, usedHosts));
+  CPPUNIT_ASSERT_EQUAL((size_t)2, fileEntry_.getRemainingUris().size());
+
+  CPPUNIT_ASSERT_EQUAL(std::string("http://alpha/file"),
+                       sel->select(&fileEntry_, usedHosts));
+  CPPUNIT_ASSERT_EQUAL((size_t)1, fileEntry_.getRemainingUris().size());
+
+  CPPUNIT_ASSERT_EQUAL(std::string("ftp://alpha/file"),
+                       sel->select(&fileEntry_, usedHosts));
+  CPPUNIT_ASSERT_EQUAL((size_t)0, fileEntry_.getRemainingUris().size());
 }
 
 void FeedbackURISelectorTest::testSelect_skipErrorHost()
@@ -91,14 +115,14 @@ void FeedbackURISelectorTest::testSelect_skipErrorHost()
   alphaHTTP->setError();
   SharedHandle<ServerStat> alphaFTP(new ServerStat("alpha", "ftp"));
   alphaFTP->setError();
+  std::vector<std::pair<size_t, std::string> > usedHosts;
 
   ssm->add(alphaHTTP);
   ssm->add(alphaFTP);
 
-  // See error URIs are removed from URI List.
   CPPUNIT_ASSERT_EQUAL(std::string("http://bravo/file"),
-                       sel->select(&_fileEntry));
-  CPPUNIT_ASSERT_EQUAL((size_t)0, _fileEntry.getRemainingUris().size());
+                       sel->select(&fileEntry_, usedHosts));
+  CPPUNIT_ASSERT_EQUAL((size_t)2, fileEntry_.getRemainingUris().size());
 }
 
 } // namespace aria2
