@@ -53,7 +53,7 @@ void UTMetadataPostDownloadHandlerTest::testCanHandle()
   CPPUNIT_ASSERT(!handler.canHandle(requestGroup_.get()));
 
   SharedHandle<TorrentAttribute> attrs(new TorrentAttribute());
-  dctx_->setAttribute(bittorrent::BITTORRENT, attrs);
+  dctx_->setAttribute(CTX_ATTR_BT, attrs);
 
   CPPUNIT_ASSERT(handler.canHandle(requestGroup_.get()));
 
@@ -84,7 +84,7 @@ void UTMetadataPostDownloadHandlerTest::testGetNextRequestGroups()
   announceTier.push_back("http://tracker");
   announceList.push_back(announceTier);
   attrs->announceList = announceList;
-  dctx_->setAttribute(bittorrent::BITTORRENT, attrs);
+  dctx_->setAttribute(CTX_ATTR_BT, attrs);
   requestGroup_->setDiskWriterFactory
     (SharedHandle<DiskWriterFactory>(new ByteArrayDiskWriterFactory()));
   requestGroup_->initPieceStorage();
@@ -107,8 +107,8 @@ void UTMetadataPostDownloadHandlerTest::testGetNextRequestGroups()
     newAttrs->announceList;
   CPPUNIT_ASSERT_EQUAL((size_t)1, newAnnounceList.size());
   CPPUNIT_ASSERT_EQUAL(std::string("http://tracker"), newAnnounceList[0][0]);
-  CPPUNIT_ASSERT_EQUAL(option_->get("Hello"),
-                       newRg->getOption()->get("Hello"));
+  CPPUNIT_ASSERT_EQUAL(option_->get(PREF_DIR),
+                       newRg->getOption()->get(PREF_DIR));
   CPPUNIT_ASSERT
     (std::find(requestGroup_->followedBy().begin(),
                requestGroup_->followedBy().end(),
